// src/anchor/anchor.tsx
import { Link } from "theme-ui";

// src/icon/icon.fx.ts
var getIconClassName = (variant, className) => {
  const trimmed = variant == null ? void 0 : variant.trim();
  return trimmed === "filled" ? `material-icons ${className || ""}`.trimEnd() : `material-icons-${trimmed} ${className || ""}`.trimEnd();
};

// src/icon/icon.styles.ts
import { Size } from "@waystone/core";
var IconSize = /* @__PURE__ */ ((IconSize2) => {
  IconSize2["sm"] = "1em";
  IconSize2["md"] = "1.5em";
  IconSize2["lg"] = "2em";
  return IconSize2;
})(IconSize || {});
var convert = (size) => IconSize[Size[size]];
var iconCss = (props) => {
  const css = {
    verticalAlign: "middle",
    color: props.color || "inherit",
    fontSize: "inherit"
  };
  if (props.size) {
    css.fontSize = `${convert(props.size)} !important`;
  }
  return css;
};

// src/icon/icon.tsx
import { jsx } from "theme-ui/jsx-runtime";
var Icon = ({
  className,
  name,
  variant = "filled",
  size = "md",
  color = "inherit",
  ...rest
}) => /* @__PURE__ */ jsx("i", {
  sx: iconCss({ size, color }),
  className: getIconClassName(variant, className),
  ...rest,
  children: name
});

// src/anchor/anchor.styles.tsx
var anchorCss = {
  paddingX: "xs",
  textDecoration: "none",
  borderBottom: "1px solid",
  borderBottomColor: "highlight",
  color: "inherit",
  transition: "all 100ms",
  outline: "none",
  fontFamily: "inherit",
  fontWeight: "inherit",
  fontSize: "inherit",
  cursor: "pointer",
  ":hover, :focus": {
    backgroundColor: "muted",
    borderTopLeftRadius: "sm",
    borderTopRightRadius: "sm"
  }
};
var undecoratedAnchorCss = {
  display: "flex",
  justifyContent: "center",
  alignItems: "center",
  cursor: "pointer"
};

// src/anchor/anchor.tsx
import { jsx as jsx2, jsxs } from "theme-ui/jsx-runtime";
var InternalAnchor = ({
  children,
  noDecoration,
  ...rest
}) => /* @__PURE__ */ jsx2(Link, {
  ...rest,
  sx: noDecoration ? undecoratedAnchorCss : anchorCss,
  children
});
var ExternalAnchor = ({
  children,
  noDecoration,
  target = "_blank",
  rel = "noopener noreferrer",
  ...rest
}) => /* @__PURE__ */ jsxs(Link, {
  ...rest,
  sx: !noDecoration ? anchorCss : undecoratedAnchorCss,
  target,
  rel,
  children: [
    children,
    " ",
    /* @__PURE__ */ jsx2(Icon, {
      name: "open_in_new",
      size: "sm",
      sx: { pb: "xs" }
    })
  ]
});
var Anchor = ({ external = false, ...rest }) => {
  if (external) {
    return /* @__PURE__ */ jsx2(ExternalAnchor, {
      ...rest
    });
  }
  return /* @__PURE__ */ jsx2(InternalAnchor, {
    ...rest
  });
};

// src/button/button.tsx
import React3 from "react";
import {
  Button as ThemeUiButton,
  Flex
} from "theme-ui";

// src/spinner/spinner.styles.ts
import { keyframes } from "@emotion/react";
var changeContent = keyframes`
10% { content: "⠙"; }
20% { content: "⠹"; }
30% { content: "⠸"; }
40% { content: "⠼"; }
50% { content: "⠴"; }
60% { content: "⠦"; }
70% { content: "⠧"; }
80% { content: "⠇"; }
90% { content: "⠏"; }
`;
var getSpinnerSize = (size) => {
  switch (size) {
    case "sm":
      return "1.3125rem";
    case "md":
      return "1.5em";
    case "lg":
      return "2em";
    default:
      return "1.5em";
  }
};
var spinnerCss = ({
  size,
  color,
  fullWidth
}) => {
  const css = {
    color,
    display: fullWidth ? "flex" : "inline-flex",
    width: fullWidth ? "100%" : "auto",
    height: getSpinnerSize(size || "md"),
    alignItems: "center",
    justifyContent: "center",
    aspectRatio: "1",
    ":after": {
      animation: `${changeContent} 600ms linear infinite`,
      display: "block",
      content: '"\u280B"',
      fontSize: getSpinnerSize(size || "md")
    }
  };
  return css;
};

// src/overlay/overlay.tsx
import { alpha } from "@theme-ui/color";
import { jsx as jsx3 } from "theme-ui/jsx-runtime";
var Overlay = ({ children, fullScreen = false }) => /* @__PURE__ */ jsx3("div", {
  sx: {
    position: fullScreen ? "fixed" : "absolute",
    top: 0,
    left: 0,
    width: "100%",
    height: "100%",
    zIndex: "highest",
    bg: alpha("muted", 0.9),
    backdropFilter: "blur(10px)"
  },
  children: /* @__PURE__ */ jsx3("div", {
    sx: { opacity: 1 },
    children
  })
});

// src/spinner/spinner.tsx
import { jsx as jsx4 } from "theme-ui/jsx-runtime";
var Spinner = ({
  size = "md",
  color = "accent",
  fullWidth = false,
  overlay = false
}) => {
  if (overlay) {
    return /* @__PURE__ */ jsx4(Overlay, {
      children: /* @__PURE__ */ jsx4("span", {
        sx: {
          ...spinnerCss({ size, color, fullWidth: true }),
          height: "100%",
          zIndex: "highest",
          position: "absolute"
        }
      })
    });
  }
  return /* @__PURE__ */ jsx4("span", {
    role: "progressbar",
    sx: spinnerCss({ size, color, fullWidth }),
    "aria-valuetext": "Loading...",
    "aria-busy": true
  });
};

// src/spinner/spinner.hoc.tsx
import { jsx as jsx5 } from "theme-ui/jsx-runtime";
function withSpinner(WrappedComponent) {
  const ComponentWithSpinner = (props) => {
    const { loading } = props;
    return loading ? /* @__PURE__ */ jsx5(Spinner, {
      ...props
    }) : /* @__PURE__ */ jsx5(WrappedComponent, {
      ...props
    });
  };
  return ComponentWithSpinner;
}

// src/spinner/spinner.hooks.tsx
import React from "react";
import { jsx as jsx6 } from "theme-ui/jsx-runtime";
var useSpinner = (props) => {
  var _a, _b;
  const [visible, setVisible] = React.useState((_a = props == null ? void 0 : props.initialVisible) != null ? _a : false);
  const show = () => setVisible(true);
  const hide = () => setVisible(false);
  const spinner = visible && /* @__PURE__ */ jsx6(Spinner, {
    overlay: (_b = props == null ? void 0 : props.overlay) != null ? _b : true
  });
  return { show, hide, spinner };
};

// src/spinner/spinner.context.tsx
import React2 from "react";
import { jsxs as jsxs2 } from "theme-ui/jsx-runtime";
var SpinnerContext = React2.createContext({});
var SpinnerProvider = ({ initialVisible = true, children }) => {
  const { show, hide, spinner } = useSpinner({ initialVisible });
  const value = React2.useMemo(() => ({ show, hide }), [show, hide]);
  return /* @__PURE__ */ jsxs2(SpinnerContext.Provider, {
    value,
    children: [
      children,
      spinner
    ]
  });
};
var useSpinnerContext = () => {
  const context = React2.useContext(SpinnerContext);
  if (!context) {
    throw new Error(
      '"useSpinnerContext" must be used within a "SpinnerProvider"'
    );
  }
  return context;
};

// src/text/text.tsx
import { Text as ThemeUiText } from "theme-ui";

// src/text/text.styles.ts
var textCss = ({
  inline,
  variant,
  color
}) => {
  const css = {
    display: "block",
    variant: `text.${variant}`,
    color: color || "inherit"
  };
  if (inline) {
    css.display = "inline-block";
    css.marginY = 0;
    css.marginX = 0;
  }
  return css;
};

// src/text/text.tsx
import { jsx as jsx7 } from "theme-ui/jsx-runtime";
var Text = ({
  children,
  as = "span",
  inline = false,
  variant = "body",
  color,
  ...rest
}) => /* @__PURE__ */ jsx7(ThemeUiText, {
  sx: textCss({ inline, variant, color }),
  as,
  ...rest,
  children
});

// src/hooks/useIsDarkMode.tsx
import { useColorMode } from "theme-ui";
var useIsDarkMode = () => {
  const [colorMode] = useColorMode();
  const darkMode = colorMode === "dark";
  return darkMode;
};

// src/button/button.styles.ts
import { alpha as alpha2 } from "@theme-ui/color";

// src/button/button.styles.fx.ts
import { addDarkModeSuffix } from "@waystone/core";
var getBackgroundColor = ({
  variant = "primary"
}) => {
  switch (variant) {
    case "ghost":
      return "ghost";
    case "link":
      return "transparent";
    case "primary":
    case "secondary":
    case "accent":
    case "highlight":
    default:
      return `${variant[0]}-400`;
  }
};
var getHoverBackgroundColor = ({
  variant = "primary",
  darkMode
}) => {
  switch (variant) {
    case "ghost":
      return darkMode ? "b-500" : "b-000";
    case "link":
      return "transparent";
    case "primary":
    case "secondary":
    case "accent":
    case "highlight":
    default:
      return `${variant[0]}-300`;
  }
};
var getActiveBackgroundColor = ({
  variant = "primary",
  darkMode
}) => {
  switch (variant) {
    case "ghost":
      return darkMode ? "b-500" : "white";
    case "link":
      return "transparent";
    case "primary":
    case "secondary":
    case "accent":
    case "highlight":
    default:
      return `${variant[0]}-200`;
  }
};
var getColor = (variant) => {
  switch (variant) {
    case "primary":
    case "secondary":
    case "accent":
    case "highlight":
      return "b-600";
    default:
      return "text";
  }
};
var getLinkVariantActiveColor = (darkMode) => darkMode ? "h-400" : "h-700";
var getLinkVariantHoverColor = (darkMode) => darkMode ? "h-300" : "h-600";
var getBoxShadow = ({
  variant = "primary",
  darkMode
}) => {
  if (["ghost", "link"].includes(variant)) {
    return {
      normalBoxShadow: "none",
      hoverBoxShadow: "none",
      activeBoxShadow: "none"
    };
  }
  return {
    normalBoxShadow: addDarkModeSuffix("sm", darkMode),
    hoverBoxShadow: addDarkModeSuffix("md", darkMode),
    activeBoxShadow: addDarkModeSuffix("sm", darkMode)
  };
};
var getPadding = ({
  variant = "primary",
  size
}) => {
  if (variant === "link")
    return { paddingX: 0, paddingY: 0 };
  switch (size) {
    case "sm": {
      return {
        paddingX: "sm",
        paddingY: "xs"
      };
    }
    case "lg": {
      return {
        paddingX: "xl",
        paddingY: "sm"
      };
    }
    default:
      return {
        paddingX: "lg",
        paddingY: "sm"
      };
  }
};

// src/button/button.styles.ts
var buttonCss = ({
  variant,
  size,
  darkMode,
  width,
  minWidth,
  maxWidth,
  fullWidth,
  active
}) => {
  const { normalBoxShadow, hoverBoxShadow, activeBoxShadow } = getBoxShadow({
    variant,
    darkMode
  });
  const { paddingX, paddingY } = getPadding({ variant, size });
  const color = getColor(variant);
  const outlineColor = darkMode ? "b-600" : "info-000";
  const isLink = variant === "link";
  const hoverCss = {
    color: isLink ? getLinkVariantHoverColor(darkMode) : color,
    boxShadow: hoverBoxShadow,
    backgroundColor: getHoverBackgroundColor({ variant, darkMode })
  };
  const focusCss = {
    color: isLink ? getLinkVariantActiveColor(darkMode) : color,
    boxShadow: activeBoxShadow,
    backgroundColor: getActiveBackgroundColor({ variant, darkMode }),
    outlineColor: alpha2(outlineColor, 1),
    outlineWidth: "sm",
    outlineStyle: "solid"
  };
  const activeCss = {
    color: isLink ? getLinkVariantActiveColor(darkMode) : color,
    boxShadow: activeBoxShadow,
    backgroundColor: getActiveBackgroundColor({ variant, darkMode }),
    outlineColor: alpha2(outlineColor, 0),
    outlineWidth: "sm",
    outlineStyle: "solid"
  };
  const baseCss = {
    display: "flex",
    flexWrap: "nowrap",
    alignItems: "center",
    justifyContent: "center",
    color,
    backgroundColor: getBackgroundColor({ variant, darkMode }),
    paddingX,
    paddingY,
    width: fullWidth ? "100%" : width,
    maxWidth: !fullWidth && maxWidth,
    minWidth: !fullWidth && minWidth,
    boxShadow: normalBoxShadow,
    margin: 0,
    cursor: "pointer",
    transition: "all 200ms ease",
    outlineColor: alpha2(outlineColor, 0),
    outlineWidth: "sm",
    outlineStyle: "solid",
    ":enabled:hover": {
      ...hoverCss
    },
    ":not(active):focus": {
      ...focusCss
    },
    ":enabled:active": {
      ...activeCss
    },
    ":disabled": {
      color: "b-400",
      backgroundColor: !isLink && "muted",
      cursor: "not-allowed"
    }
  };
  if (active) {
    return { ...baseCss, ...activeCss };
  }
  return baseCss;
};
var buttonAddonCss = ({
  hasChildren,
  variant,
  size
}) => ({
  marginRight: hasChildren && "sm",
  marginY: getPadding({ variant, size })
});

// src/button/button.fx.ts
var getTextVariant = (size) => {
  switch (size) {
    case "sm":
      return "caption";
    case "lg":
      return "eyebrow";
    default:
      return "body";
  }
};

// src/button/button.tsx
import { jsx as jsx8, jsxs as jsxs3 } from "theme-ui/jsx-runtime";
var Button = ({
  children,
  icon,
  width,
  minWidth,
  maxWidth,
  fullWidth,
  variant = "primary",
  size = "sm",
  hideContentWhileLoading = false,
  loading = false,
  disabled = false,
  active = false,
  ...rest
}) => {
  const isDarkMode = useIsDarkMode();
  const shouldBeDisabled = disabled || loading;
  const shouldRenderChildren = !!children && (!loading || !hideContentWhileLoading);
  const shouldRenderIcon = !loading && icon;
  const buttonSx = React3.useMemo(() => {
    const buttonCssParams = {
      variant,
      size,
      darkMode: isDarkMode,
      active,
      width,
      minWidth,
      maxWidth,
      fullWidth
    };
    return buttonCss(buttonCssParams);
  }, [variant, size, isDarkMode, active, width, minWidth, maxWidth, fullWidth]);
  const buttonAddonSx = React3.useMemo(() => {
    const buttonAddonCssParams = {
      variant,
      size,
      hasChildren: shouldRenderChildren
    };
    return buttonAddonCss(buttonAddonCssParams);
  }, [variant, size, shouldRenderChildren]);
  const spinnerSize = size === "sm" ? "sm" : "md";
  return /* @__PURE__ */ jsxs3(ThemeUiButton, {
    sx: buttonSx,
    disabled: shouldBeDisabled,
    ...rest,
    children: [
      loading && /* @__PURE__ */ jsx8(Flex, {
        sx: buttonAddonSx,
        children: /* @__PURE__ */ jsx8(Spinner, {
          size: spinnerSize
        })
      }),
      shouldRenderIcon && /* @__PURE__ */ jsx8(Flex, {
        sx: buttonAddonSx,
        children: /* @__PURE__ */ jsx8(Icon, {
          size: "sm",
          ...icon
        })
      }),
      shouldRenderChildren && /* @__PURE__ */ jsx8(Text, {
        variant: getTextVariant(size),
        inline: true,
        children
      })
    ]
  });
};

// src/button-group/buttonGroup.tsx
import { Flex as Flex2 } from "theme-ui";

// src/button-group/buttonGroup.styles.ts
var buttonGroupCss = {
  gap: "xs",
  padding: "xs",
  borderRadius: "sm",
  backgroundColor: "ghost",
  width: "fit-content"
};

// src/button-group/buttonGroup.tsx
import { jsx as jsx9 } from "theme-ui/jsx-runtime";
import { createElement } from "theme-ui";
var ButtonGroup = ({
  activeButton,
  buttons,
  onChange
}) => /* @__PURE__ */ jsx9(Flex2, {
  sx: buttonGroupCss,
  children: buttons.map((button) => {
    if (!button.id) {
      throw new Error("You must provide an `id` for each button");
    }
    const key = button.id;
    return /* @__PURE__ */ createElement(Button, {
      ...button,
      key,
      variant: "ghost",
      active: key === activeButton,
      onClick: (e) => {
        if (onChange)
          onChange({ e, clicked: key });
      }
    });
  })
});

// src/card/card.tsx
import { useColorMode as useColorMode2 } from "theme-ui";

// src/card/card.styles.ts
var cardContainerCss = ({
  fullWidth,
  width,
  minWidth,
  maxWidth,
  noShadow,
  darkMode,
  ...rest
}) => ({
  borderRadius: "md",
  width: fullWidth ? "100%" : width || "auto",
  minWidth: !fullWidth && minWidth,
  maxWidth: !fullWidth && maxWidth,
  backgroundColor: darkMode ? "b-600" : "b-000",
  boxShadow: !noShadow && "md",
  overflowY: "auto",
  ...rest
});
var coverImageCss = ({
  url,
  size = "cover",
  repeat = "no-repeat",
  position = "center",
  height = "md",
  fallbackColor = "secondary"
}) => ({
  backgroundImage: `url(${url})`,
  backgroundColor: fallbackColor,
  backgroundSize: size,
  backgroundRepeat: repeat,
  backgroundPosition: position,
  width: "100%",
  height
});
var cardContentCss = (noPadding) => ({
  padding: noPadding ? 0 : "md"
});

// src/card/card.tsx
import { jsx as jsx10, jsxs as jsxs4 } from "theme-ui/jsx-runtime";
var Card = ({
  children,
  coverImage,
  noPadding,
  ...rest
}) => {
  const [mode] = useColorMode2();
  const darkMode = mode === "dark";
  return /* @__PURE__ */ jsxs4("div", {
    sx: cardContainerCss({
      ...rest,
      darkMode
    }),
    children: [
      coverImage && /* @__PURE__ */ jsx10("div", {
        sx: coverImageCss(coverImage),
        role: "img"
      }),
      /* @__PURE__ */ jsx10("div", {
        sx: cardContentCss(noPadding),
        children
      })
    ]
  });
};

// src/card-button/cardButton.tsx
import { alpha as alpha3 } from "@theme-ui/color";
import { jsx as jsx11, jsxs as jsxs5 } from "theme-ui/jsx-runtime";
var CardButton = ({
  children,
  fullWidth,
  width,
  minWidth,
  maxWidth,
  noShadow,
  disabled,
  loading,
  onClick,
  ...rest
}) => {
  const darkMode = useIsDarkMode();
  const cardCss = {
    position: "relative",
    paddingX: "md",
    paddingY: "md",
    border: "none",
    borderRadius: "md",
    color: "text",
    width: fullWidth ? "100%" : width || "auto",
    minWidth: !fullWidth && minWidth,
    maxWidth: !fullWidth && maxWidth,
    backgroundColor: darkMode ? "b-600" : "b-000",
    boxShadow: !noShadow && "md",
    cursor: "pointer",
    outlineColor: alpha3("info-000", 0),
    outlineWidth: "sm",
    outlineStyle: "solid",
    overflow: "hidden",
    textAlign: "left",
    transition: "all 200ms",
    ...rest,
    ":enabled:hover": {
      backgroundColor: darkMode ? "b-500" : "b-100"
    },
    ":enabled:focus": {
      outlineColor: alpha3("info-000", 0.75),
      outlineWidth: "sm",
      outlineStyle: "solid"
    },
    ":enabled:active": {
      backgroundColor: darkMode ? "b-400" : "b-200"
    },
    ":disabled": {
      color: "b-400",
      backgroundColor: "muted",
      cursor: "not-allowed"
    }
  };
  return /* @__PURE__ */ jsxs5("button", {
    sx: cardCss,
    onClick,
    type: "button",
    disabled: disabled || loading,
    children: [
      loading && /* @__PURE__ */ jsx11(Spinner, {
        overlay: true
      }),
      children
    ]
  });
};

// src/code/code.tsx
import { useColorMode as useColorMode3 } from "theme-ui";

// src/code/code.styles.ts
var codeCss = (darkMode) => ({
  variant: "text.mono",
  fontSize: "caption",
  backgroundColor: darkMode ? "b-600" : "b-200",
  borderRadius: "sm",
  px: "xs",
  py: 2,
  color: darkMode ? "highlight" : "b-600"
});

// src/code/code.tsx
import { jsx as jsx12 } from "theme-ui/jsx-runtime";
var Code = ({ children }) => {
  const [mode] = useColorMode3();
  return /* @__PURE__ */ jsx12("code", {
    sx: codeCss(mode === "dark"),
    children
  });
};

// src/code-block/codeBlock.tsx
import React4 from "react";
import SyntaxHighlighter from "react-syntax-highlighter";
import { tomorrowNight } from "react-syntax-highlighter/dist/cjs/styles/hljs";

// src/code-block/codeBlock.fx.ts
var copy = (text) => {
  navigator.clipboard.writeText(text);
};

// src/code-block/codeBlock.styles.ts
import { alpha as alpha4 } from "@theme-ui/color";
var codeBlockContainerCss = {
  backgroundColor: "b-600",
  px: "md",
  mb: "lg",
  mx: "md",
  borderRadius: "md",
  variant: "text.monospace",
  display: "block",
  position: "relative",
  overflow: "clip"
};
var codeBlockLanguageCss = {
  variant: "text.small",
  letterSpacing: 1.25,
  fontWeight: "medium",
  position: "absolute",
  top: 0,
  left: "1.5rem",
  backgroundColor: "a-600",
  padding: "xs",
  color: "b-000",
  textTransform: "uppercase",
  boxShadow: "sm-dark",
  borderBottomLeftRadius: "sm",
  borderBottomRightRadius: "sm",
  pointerEvents: "none"
};
var codeBlockCopyButtonCss = {
  variant: "text.small",
  letterSpacing: 1.25,
  fontWeight: "medium",
  position: "absolute",
  top: 0,
  right: "1.5rem",
  padding: "xs",
  background: "b-500",
  boxShadow: "sm-dark",
  border: "none",
  borderBottomLeftRadius: "sm",
  borderBottomRightRadius: "sm",
  color: "b-000",
  textTransform: "uppercase",
  cursor: "pointer",
  transition: "all 200ms",
  outlineColor: alpha4("info-000", 0),
  outlineWidth: "xs",
  outlineStyle: "solid",
  ":hover": {
    background: "b-400"
  },
  ":focus": {
    outlineColor: alpha4("info-000", 0.75),
    outlineWidth: "xs",
    outlineStyle: "solid"
  },
  ":active": {
    background: "b-300"
  }
};
var codeBlockCaptionCss = {
  position: "absolute",
  variant: "text.caption",
  textAlign: "center",
  bottom: 0,
  left: 0,
  right: 0,
  padding: "xs",
  backgroundColor: "b-700",
  color: "b-000"
};

// src/code-block/codeBlock.tsx
import { jsx as jsx13, jsxs as jsxs6 } from "theme-ui/jsx-runtime";
var CodeBlock = ({
  language = "text",
  wordWrap = false,
  hideLineNumbers = false,
  caption,
  children
}) => {
  const [iconName, setIconName] = React4.useState("content_copy");
  const handleCopy = () => {
    copy(children);
    setIconName("done");
  };
  const handleBlur = () => {
    setIconName("content_copy");
  };
  return /* @__PURE__ */ jsxs6("div", {
    sx: codeBlockContainerCss,
    children: [
      /* @__PURE__ */ jsx13("div", {
        sx: codeBlockLanguageCss,
        children: language
      }),
      /* @__PURE__ */ jsx13("button", {
        sx: codeBlockCopyButtonCss,
        type: "button",
        onClick: handleCopy,
        onBlur: handleBlur,
        children: /* @__PURE__ */ jsx13(Icon, {
          name: iconName
        })
      }),
      /* @__PURE__ */ jsx13(SyntaxHighlighter, {
        wrapLongLines: wordWrap,
        showLineNumbers: !hideLineNumbers,
        language,
        style: tomorrowNight,
        customStyle: {
          backgroundColor: "inherit",
          fontFamily: "inherit",
          fontWeight: "inherit",
          lineHeight: "inherit",
          paddingTop: "2rem",
          paddingBottom: caption ? "2.25rem" : "1.5rem"
        },
        children
      }),
      caption && /* @__PURE__ */ jsx13("div", {
        sx: codeBlockCaptionCss,
        children: caption
      })
    ]
  });
};

// src/input-container/inputContainer.tsx
import { Flex as Flex3 } from "theme-ui";

// src/label/label.tsx
import { jsx as jsx14 } from "theme-ui/jsx-runtime";
var Label = ({ htmlFor, children }) => {
  const darkMode = useIsDarkMode();
  const labelCss2 = {
    textTransform: "capitalize",
    color: darkMode ? "b-300" : "b-500",
    fontWeight: "medium",
    fontSize: "caption"
  };
  return /* @__PURE__ */ jsx14("label", {
    sx: labelCss2,
    htmlFor,
    children
  });
};

// src/input-container/inputContainer.styles.ts
var inputContainerCss = ({
  width,
  minWidth,
  maxWidth
}) => {
  const baseCss = {
    flexDirection: "column"
  };
  return { ...baseCss, width, minWidth, maxWidth };
};
var labelContainerCss = {
  justifyContent: "space-between",
  alignItems: "baseline",
  marginBottom: "xs"
};
var labelCss = {
  alignItems: "center",
  gap: "xs"
};

// src/input-container/inputContainer.fx.ts
var getIconName = (variant) => {
  switch (variant) {
    case "success":
      return "check_circle";
    case "error":
      return "error";
    case "warning":
      return "warning";
    default:
      return "info";
  }
};
var getVariantColor = (variant) => variant ? `${variant}-400` : "b-400";

// src/input-container/inputContainer.tsx
import { jsx as jsx15, jsxs as jsxs7 } from "theme-ui/jsx-runtime";
var InputContainer = ({
  id,
  label,
  children,
  helpText,
  variant,
  required,
  ...rest
}) => {
  const color = getVariantColor(variant);
  return /* @__PURE__ */ jsxs7(Flex3, {
    sx: inputContainerCss({ ...rest }),
    children: [
      /* @__PURE__ */ jsxs7(Flex3, {
        sx: labelContainerCss,
        children: [
          /* @__PURE__ */ jsxs7(Flex3, {
            sx: labelCss,
            children: [
              /* @__PURE__ */ jsx15(Label, {
                htmlFor: id,
                children: label
              }),
              variant && /* @__PURE__ */ jsx15(Icon, {
                color,
                name: getIconName(variant),
                size: "sm"
              })
            ]
          }),
          required && /* @__PURE__ */ jsx15(Text, {
            variant: "small",
            color: "error-400",
            inline: true,
            children: "required"
          })
        ]
      }),
      children,
      helpText && /* @__PURE__ */ jsx15(Text, {
        variant: "small",
        color,
        inline: true,
        children: helpText
      })
    ]
  });
};

// src/waystone-ui/waystoneUi.tsx
import { useEffect } from "react";
import { ThemeProvider } from "theme-ui";
import { WaystoneBaseTheme, mergeObjects } from "@waystone/core";
import { jsx as jsx16 } from "theme-ui/jsx-runtime";
var baseTextFont = "https://fonts.googleapis.com/css2?family=Barlow:wght@200;300;400;500;600;700&family=Fira+Code&display=swap";
var baseIconFont = "https://fonts.googleapis.com/icon?family=Material+Icons|Material+Icons+Outlined|Material+Icons+Two+Tone|Material+Icons+Round|Material+Icons+Sharp";
var addFonts = (options) => {
  const fonts = {
    text: (options == null ? void 0 : options.textFont) || baseTextFont,
    icons: (options == null ? void 0 : options.iconFont) || baseIconFont
  };
  if (!document.getElementById("fontsPreconnect")) {
    const preconnectLink = document.createElement("link");
    preconnectLink.id = "fontsPreconnect";
    preconnectLink.rel = "preconnect";
    preconnectLink.href = "https://fonts.gstatic.com";
    document.head.appendChild(preconnectLink);
  }
  Object.keys(fonts).forEach((key) => {
    const linkExists = document.getElementById(key);
    if (!linkExists) {
      const link = document.createElement("link");
      link.id = key;
      link.rel = "stylesheet";
      link.href = fonts[key];
      link.crossOrigin = "anonymous";
      document.head.appendChild(link);
    }
  });
};
var Waystone = ({
  theme,
  fontOptions,
  children
}) => {
  const parsedTheme = JSON.parse(JSON.stringify(WaystoneBaseTheme));
  useEffect(() => {
    addFonts(fontOptions);
  }, [fontOptions]);
  if (theme) {
    mergeObjects(parsedTheme, theme);
  }
  return /* @__PURE__ */ jsx16(ThemeProvider, {
    theme: parsedTheme,
    children
  });
};
export {
  Anchor,
  Button,
  ButtonGroup,
  Card,
  CardButton,
  Code,
  CodeBlock,
  Icon,
  InputContainer,
  Label,
  Overlay,
  Spinner,
  SpinnerContext,
  SpinnerProvider,
  Text,
  Waystone,
  useIsDarkMode,
  useSpinner,
  useSpinnerContext,
  withSpinner
};
